# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-10 08:03
from __future__ import unicode_literals

from django.db import migrations


def move_hour_registrations(apps, schema_editor):
    """
    Move all ProductionEvent hours to Finances model.
    """
    ProductionEvent = apps.get_model('production', 'ProductionEvent')
    WorkLog = apps.get_model('finances', 'WorkLog')
    ContentType = apps.get_model('contenttypes', 'ContentType')
    stream_content_type = ContentType.objects.get(app_label='production', model='productionstream')

    for event in ProductionEvent.objects.filter(duration__isnull=False):
        if event.event in ['assigned_to_supervisor',
                           'message_edadmin_to_supervisor',
                           'message_supervisor_to_edadmin',
                           'officer_tasked_with_proof_production',
                           'message_supervisor_to_officer',
                           'proofs_checked_by_supervisor',
                           'proofs_returned_by_authors',
                           'proofs_returned_by_authors',
                           'authors_have_accepted_proofs',
                           'paper_published']:
            _type = 'Production: Supervisory tasks'
        else:
            _type = 'Production: Production Officer tasks'

        log = WorkLog(
            user=event.noted_by.user,
            log_type=_type,
            comments=event.comments,
            duration=event.duration,
            work_date=event.noted_on,
            content_type=stream_content_type,
            object_id=event.stream.id
        )
        log.save()
    return


def move_hour_registrations_inverse(apps, schema_editor):
    """
    Move all ProductionEvent hours to Finances model inversed (not implemented).
    """
    return


class Migration(migrations.Migration):

    dependencies = [
        ('finances', '0005_auto_20171010_0921'),
    ]

    operations = [
        migrations.RunPython(move_hour_registrations, move_hour_registrations_inverse)
    ]
